@@ -1,20 +1,16 @@
 import logging
 import unittest
+from cbpi.cli import CraftBeerPiCli
 
-from cli import add, remove, list_plugins
+from cbpi.configFolder import ConfigFolder
 
 logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(name)s - %(message)s')
 
-
 class CLITest(unittest.TestCase):
 
-    def test_install(self):
-        assert add("cbpi4-ui-plugin") == True
-        assert add("cbpi4-ui-plugin") == False
-        assert remove("cbpi4-ui-plugin") == True
-
     def test_list(self):
-        list_plugins()
+        cli = CraftBeerPiCli(ConfigFolder("./cbpi-test-config"))
+        cli.plugins_list()
 
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
